@@ -275,7 +275,7 @@ class Ner():
         self.model.to(self._target_device)
         with torch.no_grad():
             for _ in trange(1, desc="Evaluating", disable=not show_progress_bar):
-                for features in dataloader:
+                for features in tqdm(dataloader):
                     features['output_all_encoded_layers']=output_all_encoded_layers
                     batch_predicts_tags=self.getPredictions(features)
                     predictions.extend(batch_predicts_tags)
